@@ -55,35 +55,6 @@ pub fn load_tools() {
     let core_tools = CORE_PLUGINS.values().cloned().collect::<Vec<ABackend>>();
     let mut tools = core_tools;
     time!("load_tools core");
-    let plugins = install_state::list_plugins()
-        .map_err(|err| {
-            warn!("{err:#}");
-        })
-        .unwrap_or_default();
-    if !SETTINGS.disable_backends.contains(&"asdf".to_string()) {
-        tools.extend(
-            plugins
-                .iter()
-                .filter(|(_, p)| **p == PluginType::Asdf)
-                .map(|(p, _)| {
-                    arg_to_backend(BackendArg::new(p.to_string(), Some(format!("asdf:{p}"))))
-                        .unwrap()
-                }),
-        );
-    }
-    time!("load_tools asdf");
-    if !SETTINGS.disable_backends.contains(&"vfox".to_string()) {
-        tools.extend(
-            plugins
-                .iter()
-                .filter(|(_, p)| **p == PluginType::Vfox)
-                .map(|(p, _)| {
-                    arg_to_backend(BackendArg::new(p.to_string(), Some(format!("vfox:{p}"))))
-                        .unwrap()
-                }),
-        );
-    }
-    time!("load_tools vfox");
     tools.extend(
         install_state::list_tools()
             .map_err(|err| {
@@ -91,10 +62,15 @@ pub fn load_tools() {
             })
             .unwrap_or_default()
             .into_values()
-            .flat_map(|ist| arg_to_backend(BackendArg::new(ist.short, Some(ist.full)))),
+            .flat_map(|ist| arg_to_backend(ist.into())),
     );
     time!("load_tools install_state");
     tools.retain(|backend| !SETTINGS.disable_tools().contains(backend.id()));
+    tools.retain(|backend| {
+        !SETTINGS
+            .disable_backends
+            .contains(&backend.get_type().to_string())
+    });
 
     let tools: BackendMap = tools
         .into_iter()
@@ -156,8 +132,8 @@ pub trait Backend: Debug + Send + Sync {
     fn id(&self) -> &str {
         &self.ba().short
     }
-    fn name(&self) -> &str {
-        &self.ba().tool_name
+    fn tool_name(&self) -> String {
+        self.ba().tool_name()
     }
     fn get_type(&self) -> BackendType {
         BackendType::Core
@@ -183,6 +159,7 @@ pub trait Backend: Debug + Send + Sync {
             let tvr = ToolRequest::System {
                 backend: ba.clone(),
                 source: ToolSource::Unknown,
+                options: Default::default(),
                 os: None,
             };
             if let Ok(backend) = ba.backend() {
@@ -334,6 +311,7 @@ pub trait Backend: Debug + Send + Sync {
             .get_all_dependencies(&ToolRequest::System {
                 backend: self.id().into(),
                 source: ToolSource::Unknown,
+                options: Default::default(),
                 os: None,
             })?
             .into_iter()
@@ -395,7 +373,7 @@ pub trait Backend: Debug + Send + Sync {
             return Err(e);
         }
 
-        self.write_backend_meta()?;
+        install_state::write_backend_meta(self.ba())?;
 
         self.cleanup_install_dirs(&ctx.tv);
         // attempt to touch all the .tool-version files to trigger updates in hook-env
@@ -539,8 +517,9 @@ pub trait Backend: Debug + Send + Sync {
         let config = Config::get();
         let dependencies = self
             .get_all_dependencies(&ToolRequest::System {
-                backend: self.name().into(),
+                backend: self.tool_name().into(),
                 source: ToolSource::Unknown,
+                options: Default::default(),
                 os: None,
             })?
             .into_iter()
@@ -604,13 +583,6 @@ pub trait Backend: Debug + Send + Sync {
             })
             .clone()
     }
-
-    fn write_backend_meta(&self) -> eyre::Result<()> {
-        file::write(
-            self.ba().installs_path.join(".mise.backend"),
-            format!("{}\n{}", self.ba().short, self.ba().full()),
-        )
-    }
 }
 
 fn find_match_in_list(list: &[String], query: &str) -> Option<String> {
