@@ -1,4 +1,4 @@
-use std::collections::{BTreeMap, HashSet};
+use std::collections::{BTreeMap, BTreeSet, HashSet};
 use std::fmt::{Debug, Display};
 
 use indexmap::IndexMap;
@@ -7,6 +7,7 @@ use itertools::Itertools;
 use crate::cli::args::{BackendArg, ToolArg};
 use crate::config::{Config, Settings};
 use crate::env;
+use crate::registry::REGISTRY;
 use crate::toolset::{ToolRequest, ToolSource};
 
 #[derive(Debug, Default, Clone)]
@@ -73,9 +74,15 @@ impl ToolRequestSet {
         })
     }
 
-    pub fn filter_by_tool(&self, tools: &HashSet<BackendArg>) -> Self {
+    pub fn filter_by_tool(&self, mut tools: HashSet<String>) -> ToolRequestSet {
+        // add in the full names so something like cargo:cargo-binstall can be used in place of cargo-binstall
+        for short in tools.clone().iter() {
+            if let Some(rt) = REGISTRY.get(short.as_str()) {
+                tools.extend(rt.backends().iter().map(|s| s.to_string()));
+            }
+        }
         self.iter()
-            .filter(|(fa, ..)| tools.contains(fa))
+            .filter(|(ba, ..)| tools.contains(&ba.short))
             .map(|(fa, trl, ts)| (fa.clone(), trl.clone(), ts.clone()))
             .collect::<ToolRequestSet>()
     }
@@ -111,14 +118,14 @@ pub struct ToolRequestSetBuilder {
     /// default to latest version if no version is specified (for `mise x`)
     default_to_latest: bool,
     /// tools which will be disabled
-    disable_tools: Vec<BackendArg>,
+    disable_tools: BTreeSet<BackendArg>,
 }
 
 impl ToolRequestSetBuilder {
     pub fn new() -> Self {
         let settings = Settings::get();
         Self {
-            disable_tools: settings.disable_tools.iter().map(|s| s.into()).collect(),
+            disable_tools: settings.disable_tools().iter().map(|s| s.into()).collect(),
             ..Default::default()
         }
     }
@@ -152,8 +159,8 @@ impl ToolRequestSetBuilder {
         Ok(trs)
     }
 
-    fn is_disabled(&self, fa: &BackendArg) -> bool {
-        self.disable_tools.contains(fa)
+    fn is_disabled(&self, ba: &BackendArg) -> bool {
+        !ba.is_os_supported() || self.disable_tools.contains(ba)
     }
 
     fn load_config_files(&self, trs: &mut ToolRequestSet) -> eyre::Result<()> {
